# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, auto_renew=None, charge_status=None, charge_type=None, cold_storage=None, create_time=None, deletion_protection=None, enable_auth=None, enable_cloud_storage=None, endpoints=None, engine_version=None, id=None, instance_id=None, instance_name=None, instance_type=None, master_count=None, master_spec=None, multi_az=None, primary_subnet_id=None, primary_zone_id=None, project_name=None, purchase_months=None, region_id=None, rs_count=None, rs_spec=None, standby_subnet_id=None, standby_zone_id=None, status=None, storage_capacity=None, storage_type=None, subnet_id=None, tags=None, used_cold_storage=None, used_storage=None, vpc_id=None, vpc_name=None, zone_id=None, zone_name=None):
        if auto_renew and not isinstance(auto_renew, bool):
            raise TypeError("Expected argument 'auto_renew' to be a bool")
        pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_status and not isinstance(charge_status, str):
            raise TypeError("Expected argument 'charge_status' to be a str")
        pulumi.set(__self__, "charge_status", charge_status)
        if charge_type and not isinstance(charge_type, str):
            raise TypeError("Expected argument 'charge_type' to be a str")
        pulumi.set(__self__, "charge_type", charge_type)
        if cold_storage and not isinstance(cold_storage, int):
            raise TypeError("Expected argument 'cold_storage' to be a int")
        pulumi.set(__self__, "cold_storage", cold_storage)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if deletion_protection and not isinstance(deletion_protection, str):
            raise TypeError("Expected argument 'deletion_protection' to be a str")
        pulumi.set(__self__, "deletion_protection", deletion_protection)
        if enable_auth and not isinstance(enable_auth, bool):
            raise TypeError("Expected argument 'enable_auth' to be a bool")
        pulumi.set(__self__, "enable_auth", enable_auth)
        if enable_cloud_storage and not isinstance(enable_cloud_storage, bool):
            raise TypeError("Expected argument 'enable_cloud_storage' to be a bool")
        pulumi.set(__self__, "enable_cloud_storage", enable_cloud_storage)
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if engine_version and not isinstance(engine_version, str):
            raise TypeError("Expected argument 'engine_version' to be a str")
        pulumi.set(__self__, "engine_version", engine_version)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if master_count and not isinstance(master_count, int):
            raise TypeError("Expected argument 'master_count' to be a int")
        pulumi.set(__self__, "master_count", master_count)
        if master_spec and not isinstance(master_spec, str):
            raise TypeError("Expected argument 'master_spec' to be a str")
        pulumi.set(__self__, "master_spec", master_spec)
        if multi_az and not isinstance(multi_az, bool):
            raise TypeError("Expected argument 'multi_az' to be a bool")
        pulumi.set(__self__, "multi_az", multi_az)
        if primary_subnet_id and not isinstance(primary_subnet_id, str):
            raise TypeError("Expected argument 'primary_subnet_id' to be a str")
        pulumi.set(__self__, "primary_subnet_id", primary_subnet_id)
        if primary_zone_id and not isinstance(primary_zone_id, str):
            raise TypeError("Expected argument 'primary_zone_id' to be a str")
        pulumi.set(__self__, "primary_zone_id", primary_zone_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if purchase_months and not isinstance(purchase_months, int):
            raise TypeError("Expected argument 'purchase_months' to be a int")
        pulumi.set(__self__, "purchase_months", purchase_months)
        if region_id and not isinstance(region_id, str):
            raise TypeError("Expected argument 'region_id' to be a str")
        pulumi.set(__self__, "region_id", region_id)
        if rs_count and not isinstance(rs_count, int):
            raise TypeError("Expected argument 'rs_count' to be a int")
        pulumi.set(__self__, "rs_count", rs_count)
        if rs_spec and not isinstance(rs_spec, str):
            raise TypeError("Expected argument 'rs_spec' to be a str")
        pulumi.set(__self__, "rs_spec", rs_spec)
        if standby_subnet_id and not isinstance(standby_subnet_id, str):
            raise TypeError("Expected argument 'standby_subnet_id' to be a str")
        pulumi.set(__self__, "standby_subnet_id", standby_subnet_id)
        if standby_zone_id and not isinstance(standby_zone_id, str):
            raise TypeError("Expected argument 'standby_zone_id' to be a str")
        pulumi.set(__self__, "standby_zone_id", standby_zone_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if storage_capacity and not isinstance(storage_capacity, int):
            raise TypeError("Expected argument 'storage_capacity' to be a int")
        pulumi.set(__self__, "storage_capacity", storage_capacity)
        if storage_type and not isinstance(storage_type, str):
            raise TypeError("Expected argument 'storage_type' to be a str")
        pulumi.set(__self__, "storage_type", storage_type)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if used_cold_storage and not isinstance(used_cold_storage, int):
            raise TypeError("Expected argument 'used_cold_storage' to be a int")
        pulumi.set(__self__, "used_cold_storage", used_cold_storage)
        if used_storage and not isinstance(used_storage, float):
            raise TypeError("Expected argument 'used_storage' to be a float")
        pulumi.set(__self__, "used_storage", used_storage)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name and not isinstance(vpc_name, str):
            raise TypeError("Expected argument 'vpc_name' to be a str")
        pulumi.set(__self__, "vpc_name", vpc_name)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)
        if zone_name and not isinstance(zone_name, str):
            raise TypeError("Expected argument 'zone_name' to be a str")
        pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> builtins.bool:
        """
        预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> builtins.str:
        """
        计费状态。取值：Normal：正常。Overdue：欠费。Shutdown：关停。
        """
        return pulumi.get(self, "charge_status")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="coldStorage")
    def cold_storage(self) -> builtins.int:
        """
        实例总容量型存储空间大小，单位 GiB。
        """
        return pulumi.get(self, "cold_storage")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        实例创建时间（UTC 时间）。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> builtins.str:
        """
        实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        """
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter(name="enableAuth")
    def enable_auth(self) -> builtins.bool:
        """
        是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        """
        return pulumi.get(self, "enable_auth")

    @property
    @pulumi.getter(name="enableCloudStorage")
    def enable_cloud_storage(self) -> builtins.bool:
        """
        是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        """
        return pulumi.get(self, "enable_cloud_storage")

    @property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetInstanceEndpointResult']:
        """
        连接地址信息列表。
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> builtins.str:
        """
        HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        """
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        实例类型。当前仅支持标准型，取值默认为 Standard。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="masterCount")
    def master_count(self) -> builtins.int:
        """
        Master 节点个数。单可用区部署，默认包含 2 个 Master 节点。
        """
        return pulumi.get(self, "master_count")

    @property
    @pulumi.getter(name="masterSpec")
    def master_spec(self) -> builtins.str:
        """
        Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        """
        return pulumi.get(self, "master_spec")

    @property
    @pulumi.getter(name="multiAz")
    def multi_az(self) -> builtins.bool:
        """
        实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        """
        return pulumi.get(self, "multi_az")

    @property
    @pulumi.getter(name="primarySubnetId")
    def primary_subnet_id(self) -> builtins.str:
        """
        实时主可用区子网 ID。
        """
        return pulumi.get(self, "primary_subnet_id")

    @property
    @pulumi.getter(name="primaryZoneId")
    def primary_zone_id(self) -> builtins.str:
        """
        实时主可用区 ID。
        """
        return pulumi.get(self, "primary_zone_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        实例所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="purchaseMonths")
    def purchase_months(self) -> builtins.int:
        """
        购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        """
        return pulumi.get(self, "purchase_months")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> builtins.str:
        """
        实例所属的地域 ID。
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="rsCount")
    def rs_count(self) -> builtins.int:
        """
        RegionServer 节点的数量。
        """
        return pulumi.get(self, "rs_count")

    @property
    @pulumi.getter(name="rsSpec")
    def rs_spec(self) -> builtins.str:
        """
        RegionServer 节点的规格码。
        """
        return pulumi.get(self, "rs_spec")

    @property
    @pulumi.getter(name="standbySubnetId")
    def standby_subnet_id(self) -> builtins.str:
        """
        实时备可用区子网 ID。
        """
        return pulumi.get(self, "standby_subnet_id")

    @property
    @pulumi.getter(name="standbyZoneId")
    def standby_zone_id(self) -> builtins.str:
        """
        实时备可用区 ID。
        """
        return pulumi.get(self, "standby_zone_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        实例当前状态。关于实例状态的更多说明，请参见实例状态说明。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageCapacity")
    def storage_capacity(self) -> builtins.int:
        """
        实例总存储容量，单位：GiB。
        """
        return pulumi.get(self, "storage_capacity")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> builtins.str:
        """
        实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        """
        需要绑定的标签键和标签值数组对象。说明支持一次传入多组标签键值对象，多组标签键值对象间用英文逗号（,）分隔。单次最多同时传入 20 组标签键值对，单个实例最多绑定 50 个标签。标签键值需满足设置规则，具体规则请参见标签设置规则。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="usedColdStorage")
    def used_cold_storage(self) -> builtins.int:
        """
        实例已使用的容量型存储空间大小，单位 MiB。
        """
        return pulumi.get(self, "used_cold_storage")

    @property
    @pulumi.getter(name="usedStorage")
    def used_storage(self) -> builtins.float:
        """
        主实例已使用的存储容量，单位：MiB。
        """
        return pulumi.get(self, "used_storage")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> builtins.str:
        """
        实例所属的私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        实例所属的可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> builtins.str:
        """
        实例所属的可用区名称。
        """
        return pulumi.get(self, "zone_name")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            auto_renew=self.auto_renew,
            charge_status=self.charge_status,
            charge_type=self.charge_type,
            cold_storage=self.cold_storage,
            create_time=self.create_time,
            deletion_protection=self.deletion_protection,
            enable_auth=self.enable_auth,
            enable_cloud_storage=self.enable_cloud_storage,
            endpoints=self.endpoints,
            engine_version=self.engine_version,
            id=self.id,
            instance_id=self.instance_id,
            instance_name=self.instance_name,
            instance_type=self.instance_type,
            master_count=self.master_count,
            master_spec=self.master_spec,
            multi_az=self.multi_az,
            primary_subnet_id=self.primary_subnet_id,
            primary_zone_id=self.primary_zone_id,
            project_name=self.project_name,
            purchase_months=self.purchase_months,
            region_id=self.region_id,
            rs_count=self.rs_count,
            rs_spec=self.rs_spec,
            standby_subnet_id=self.standby_subnet_id,
            standby_zone_id=self.standby_zone_id,
            status=self.status,
            storage_capacity=self.storage_capacity,
            storage_type=self.storage_type,
            subnet_id=self.subnet_id,
            tags=self.tags,
            used_cold_storage=self.used_cold_storage,
            used_storage=self.used_storage,
            vpc_id=self.vpc_id,
            vpc_name=self.vpc_name,
            zone_id=self.zone_id,
            zone_name=self.zone_name)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::HBase::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:hbase/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        auto_renew=pulumi.get(__ret__, 'auto_renew'),
        charge_status=pulumi.get(__ret__, 'charge_status'),
        charge_type=pulumi.get(__ret__, 'charge_type'),
        cold_storage=pulumi.get(__ret__, 'cold_storage'),
        create_time=pulumi.get(__ret__, 'create_time'),
        deletion_protection=pulumi.get(__ret__, 'deletion_protection'),
        enable_auth=pulumi.get(__ret__, 'enable_auth'),
        enable_cloud_storage=pulumi.get(__ret__, 'enable_cloud_storage'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        engine_version=pulumi.get(__ret__, 'engine_version'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        master_count=pulumi.get(__ret__, 'master_count'),
        master_spec=pulumi.get(__ret__, 'master_spec'),
        multi_az=pulumi.get(__ret__, 'multi_az'),
        primary_subnet_id=pulumi.get(__ret__, 'primary_subnet_id'),
        primary_zone_id=pulumi.get(__ret__, 'primary_zone_id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        purchase_months=pulumi.get(__ret__, 'purchase_months'),
        region_id=pulumi.get(__ret__, 'region_id'),
        rs_count=pulumi.get(__ret__, 'rs_count'),
        rs_spec=pulumi.get(__ret__, 'rs_spec'),
        standby_subnet_id=pulumi.get(__ret__, 'standby_subnet_id'),
        standby_zone_id=pulumi.get(__ret__, 'standby_zone_id'),
        status=pulumi.get(__ret__, 'status'),
        storage_capacity=pulumi.get(__ret__, 'storage_capacity'),
        storage_type=pulumi.get(__ret__, 'storage_type'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        used_cold_storage=pulumi.get(__ret__, 'used_cold_storage'),
        used_storage=pulumi.get(__ret__, 'used_storage'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vpc_name=pulumi.get(__ret__, 'vpc_name'),
        zone_id=pulumi.get(__ret__, 'zone_id'),
        zone_name=pulumi.get(__ret__, 'zone_name'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::HBase::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:hbase/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        auto_renew=pulumi.get(__response__, 'auto_renew'),
        charge_status=pulumi.get(__response__, 'charge_status'),
        charge_type=pulumi.get(__response__, 'charge_type'),
        cold_storage=pulumi.get(__response__, 'cold_storage'),
        create_time=pulumi.get(__response__, 'create_time'),
        deletion_protection=pulumi.get(__response__, 'deletion_protection'),
        enable_auth=pulumi.get(__response__, 'enable_auth'),
        enable_cloud_storage=pulumi.get(__response__, 'enable_cloud_storage'),
        endpoints=pulumi.get(__response__, 'endpoints'),
        engine_version=pulumi.get(__response__, 'engine_version'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        master_count=pulumi.get(__response__, 'master_count'),
        master_spec=pulumi.get(__response__, 'master_spec'),
        multi_az=pulumi.get(__response__, 'multi_az'),
        primary_subnet_id=pulumi.get(__response__, 'primary_subnet_id'),
        primary_zone_id=pulumi.get(__response__, 'primary_zone_id'),
        project_name=pulumi.get(__response__, 'project_name'),
        purchase_months=pulumi.get(__response__, 'purchase_months'),
        region_id=pulumi.get(__response__, 'region_id'),
        rs_count=pulumi.get(__response__, 'rs_count'),
        rs_spec=pulumi.get(__response__, 'rs_spec'),
        standby_subnet_id=pulumi.get(__response__, 'standby_subnet_id'),
        standby_zone_id=pulumi.get(__response__, 'standby_zone_id'),
        status=pulumi.get(__response__, 'status'),
        storage_capacity=pulumi.get(__response__, 'storage_capacity'),
        storage_type=pulumi.get(__response__, 'storage_type'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        used_cold_storage=pulumi.get(__response__, 'used_cold_storage'),
        used_storage=pulumi.get(__response__, 'used_storage'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vpc_name=pulumi.get(__response__, 'vpc_name'),
        zone_id=pulumi.get(__response__, 'zone_id'),
        zone_name=pulumi.get(__response__, 'zone_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCapacityInfoArgs',
    'InstanceCapacityInfoArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceCapacityInfoArgsDict(TypedDict):
        total_ti_b: NotRequired[pulumi.Input[builtins.int]]
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        used_gi_b: NotRequired[pulumi.Input[builtins.int]]
        """
        已使用容量（GiB）。
        """
elif False:
    InstanceCapacityInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceCapacityInfoArgs:
    def __init__(__self__, *,
                 total_ti_b: Optional[pulumi.Input[builtins.int]] = None,
                 used_gi_b: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] total_ti_b: 文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        :param pulumi.Input[builtins.int] used_gi_b: 已使用容量（GiB）。
        """
        if total_ti_b is not None:
            pulumi.set(__self__, "total_ti_b", total_ti_b)
        if used_gi_b is not None:
            pulumi.set(__self__, "used_gi_b", used_gi_b)

    @property
    @pulumi.getter(name="totalTiB")
    def total_ti_b(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        return pulumi.get(self, "total_ti_b")

    @total_ti_b.setter
    def total_ti_b(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "total_ti_b", value)

    @property
    @pulumi.getter(name="usedGiB")
    def used_gi_b(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        已使用容量（GiB）。
        """
        return pulumi.get(self, "used_gi_b")

    @used_gi_b.setter
    def used_gi_b(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_gi_b", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 用户标签的标签键。
        :param pulumi.Input[builtins.str] value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetUpstreamResult',
    'AwaitableGetUpstreamResult',
    'get_upstream',
    'get_upstream_output',
]

@pulumi.output_type
class GetUpstreamResult:
    """
    A collection of values returned by getUpstream.
    """
    def __init__(__self__, backend_targets=None, circuit_breaking_settings=None, comments=None, created_time=None, gateway_id=None, id=None, load_balancer_settings=None, name=None, protocol=None, source_type=None, tls_settings=None, updated_time=None, upstream_id=None, upstream_spec=None, version_details=None):
        if backend_targets and not isinstance(backend_targets, list):
            raise TypeError("Expected argument 'backend_targets' to be a list")
        pulumi.set(__self__, "backend_targets", backend_targets)
        if circuit_breaking_settings and not isinstance(circuit_breaking_settings, dict):
            raise TypeError("Expected argument 'circuit_breaking_settings' to be a dict")
        pulumi.set(__self__, "circuit_breaking_settings", circuit_breaking_settings)
        if comments and not isinstance(comments, str):
            raise TypeError("Expected argument 'comments' to be a str")
        pulumi.set(__self__, "comments", comments)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if gateway_id and not isinstance(gateway_id, str):
            raise TypeError("Expected argument 'gateway_id' to be a str")
        pulumi.set(__self__, "gateway_id", gateway_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if load_balancer_settings and not isinstance(load_balancer_settings, dict):
            raise TypeError("Expected argument 'load_balancer_settings' to be a dict")
        pulumi.set(__self__, "load_balancer_settings", load_balancer_settings)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if source_type and not isinstance(source_type, str):
            raise TypeError("Expected argument 'source_type' to be a str")
        pulumi.set(__self__, "source_type", source_type)
        if tls_settings and not isinstance(tls_settings, dict):
            raise TypeError("Expected argument 'tls_settings' to be a dict")
        pulumi.set(__self__, "tls_settings", tls_settings)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if upstream_id and not isinstance(upstream_id, str):
            raise TypeError("Expected argument 'upstream_id' to be a str")
        pulumi.set(__self__, "upstream_id", upstream_id)
        if upstream_spec and not isinstance(upstream_spec, dict):
            raise TypeError("Expected argument 'upstream_spec' to be a dict")
        pulumi.set(__self__, "upstream_spec", upstream_spec)
        if version_details and not isinstance(version_details, list):
            raise TypeError("Expected argument 'version_details' to be a list")
        pulumi.set(__self__, "version_details", version_details)

    @property
    @pulumi.getter(name="backendTargets")
    def backend_targets(self) -> Sequence['outputs.GetUpstreamBackendTargetResult']:
        """
        后端节点，Upstream来源类型为VeFaas时无效。
        """
        return pulumi.get(self, "backend_targets")

    @property
    @pulumi.getter(name="circuitBreakingSettings")
    def circuit_breaking_settings(self) -> 'outputs.GetUpstreamCircuitBreakingSettingsResult':
        """
        服务熔断配置。
        """
        return pulumi.get(self, "circuit_breaking_settings")

    @property
    @pulumi.getter
    def comments(self) -> builtins.str:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        Upstream创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> builtins.str:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="loadBalancerSettings")
    def load_balancer_settings(self) -> 'outputs.GetUpstreamLoadBalancerSettingsResult':
        """
        负载均衡配置。
        """
        return pulumi.get(self, "load_balancer_settings")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Upstream名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> builtins.str:
        """
        Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter(name="tlsSettings")
    def tls_settings(self) -> 'outputs.GetUpstreamTlsSettingsResult':
        """
        TLS配置。
        """
        return pulumi.get(self, "tls_settings")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        Upstream更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="upstreamId")
    def upstream_id(self) -> builtins.str:
        """
        Upstream ID。
        """
        return pulumi.get(self, "upstream_id")

    @property
    @pulumi.getter(name="upstreamSpec")
    def upstream_spec(self) -> 'outputs.GetUpstreamUpstreamSpecResult':
        """
        Upstream配置。
        """
        return pulumi.get(self, "upstream_spec")

    @property
    @pulumi.getter(name="versionDetails")
    def version_details(self) -> Sequence['outputs.GetUpstreamVersionDetailResult']:
        """
        Upstream版本，仅在Upstream来源类型为K8S时有效。
        """
        return pulumi.get(self, "version_details")


class AwaitableGetUpstreamResult(GetUpstreamResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUpstreamResult(
            backend_targets=self.backend_targets,
            circuit_breaking_settings=self.circuit_breaking_settings,
            comments=self.comments,
            created_time=self.created_time,
            gateway_id=self.gateway_id,
            id=self.id,
            load_balancer_settings=self.load_balancer_settings,
            name=self.name,
            protocol=self.protocol,
            source_type=self.source_type,
            tls_settings=self.tls_settings,
            updated_time=self.updated_time,
            upstream_id=self.upstream_id,
            upstream_spec=self.upstream_spec,
            version_details=self.version_details)


def get_upstream(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUpstreamResult:
    """
    Data Source schema for Byteplus::APIG::Upstream


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:apig/getUpstream:getUpstream', __args__, opts=opts, typ=GetUpstreamResult).value

    return AwaitableGetUpstreamResult(
        backend_targets=pulumi.get(__ret__, 'backend_targets'),
        circuit_breaking_settings=pulumi.get(__ret__, 'circuit_breaking_settings'),
        comments=pulumi.get(__ret__, 'comments'),
        created_time=pulumi.get(__ret__, 'created_time'),
        gateway_id=pulumi.get(__ret__, 'gateway_id'),
        id=pulumi.get(__ret__, 'id'),
        load_balancer_settings=pulumi.get(__ret__, 'load_balancer_settings'),
        name=pulumi.get(__ret__, 'name'),
        protocol=pulumi.get(__ret__, 'protocol'),
        source_type=pulumi.get(__ret__, 'source_type'),
        tls_settings=pulumi.get(__ret__, 'tls_settings'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        upstream_id=pulumi.get(__ret__, 'upstream_id'),
        upstream_spec=pulumi.get(__ret__, 'upstream_spec'),
        version_details=pulumi.get(__ret__, 'version_details'))
def get_upstream_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUpstreamResult]:
    """
    Data Source schema for Byteplus::APIG::Upstream


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:apig/getUpstream:getUpstream', __args__, opts=opts, typ=GetUpstreamResult)
    return __ret__.apply(lambda __response__: GetUpstreamResult(
        backend_targets=pulumi.get(__response__, 'backend_targets'),
        circuit_breaking_settings=pulumi.get(__response__, 'circuit_breaking_settings'),
        comments=pulumi.get(__response__, 'comments'),
        created_time=pulumi.get(__response__, 'created_time'),
        gateway_id=pulumi.get(__response__, 'gateway_id'),
        id=pulumi.get(__response__, 'id'),
        load_balancer_settings=pulumi.get(__response__, 'load_balancer_settings'),
        name=pulumi.get(__response__, 'name'),
        protocol=pulumi.get(__response__, 'protocol'),
        source_type=pulumi.get(__response__, 'source_type'),
        tls_settings=pulumi.get(__response__, 'tls_settings'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        upstream_id=pulumi.get(__response__, 'upstream_id'),
        upstream_spec=pulumi.get(__response__, 'upstream_spec'),
        version_details=pulumi.get(__response__, 'version_details')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayServiceArgs', 'GatewayService']

@pulumi.input_type
class GatewayServiceArgs:
    def __init__(__self__, *,
                 auth_spec: pulumi.Input['GatewayServiceAuthSpecArgs'],
                 gateway_id: pulumi.Input[builtins.str],
                 protocols: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 service_name: pulumi.Input[builtins.str],
                 comments: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a GatewayService resource.
        :param pulumi.Input['GatewayServiceAuthSpecArgs'] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        """
        pulumi.set(__self__, "auth_spec", auth_spec)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "protocols", protocols)
        pulumi.set(__self__, "service_name", service_name)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)

    @property
    @pulumi.getter(name="authSpec")
    def auth_spec(self) -> pulumi.Input['GatewayServiceAuthSpecArgs']:
        """
        认证配置。
        """
        return pulumi.get(self, "auth_spec")

    @auth_spec.setter
    def auth_spec(self, value: pulumi.Input['GatewayServiceAuthSpecArgs']):
        pulumi.set(self, "auth_spec", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        网关ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)


@pulumi.input_type
class _GatewayServiceState:
    def __init__(__self__, *,
                 auth_spec: Optional[pulumi.Input['GatewayServiceAuthSpecArgs']] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceCustomDomainArgs']]]] = None,
                 domain_spec: Optional[pulumi.Input['GatewayServiceDomainSpecArgs']] = None,
                 domains: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceDomainArgs']]]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering GatewayService resources.
        :param pulumi.Input['GatewayServiceAuthSpecArgs'] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input['GatewayServiceDomainSpecArgs'] domain_spec: 域名详情。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[builtins.str] gateway_name: 网关名称。
        :param pulumi.Input[builtins.str] message: 服务创建失败、删除失败或异常时的错误信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        :param pulumi.Input[builtins.str] status: Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        if auth_spec is not None:
            pulumi.set(__self__, "auth_spec", auth_spec)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if custom_domains is not None:
            pulumi.set(__self__, "custom_domains", custom_domains)
        if domain_spec is not None:
            pulumi.set(__self__, "domain_spec", domain_spec)
        if domains is not None:
            pulumi.set(__self__, "domains", domains)
        if gateway_id is not None:
            pulumi.set(__self__, "gateway_id", gateway_id)
        if gateway_name is not None:
            pulumi.set(__self__, "gateway_name", gateway_name)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if protocols is not None:
            pulumi.set(__self__, "protocols", protocols)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="authSpec")
    def auth_spec(self) -> Optional[pulumi.Input['GatewayServiceAuthSpecArgs']]:
        """
        认证配置。
        """
        return pulumi.get(self, "auth_spec")

    @auth_spec.setter
    def auth_spec(self, value: Optional[pulumi.Input['GatewayServiceAuthSpecArgs']]):
        pulumi.set(self, "auth_spec", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceCustomDomainArgs']]]]:
        return pulumi.get(self, "custom_domains")

    @custom_domains.setter
    def custom_domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceCustomDomainArgs']]]]):
        pulumi.set(self, "custom_domains", value)

    @property
    @pulumi.getter(name="domainSpec")
    def domain_spec(self) -> Optional[pulumi.Input['GatewayServiceDomainSpecArgs']]:
        """
        域名详情。
        """
        return pulumi.get(self, "domain_spec")

    @domain_spec.setter
    def domain_spec(self, value: Optional[pulumi.Input['GatewayServiceDomainSpecArgs']]):
        pulumi.set(self, "domain_spec", value)

    @property
    @pulumi.getter
    def domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceDomainArgs']]]]:
        return pulumi.get(self, "domains")

    @domains.setter
    def domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayServiceDomainArgs']]]]):
        pulumi.set(self, "domains", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关名称。
        """
        return pulumi.get(self, "gateway_name")

    @gateway_name.setter
    def gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_name", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def protocols(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("bytepluscc:apig/gatewayService:GatewayService")
class GatewayService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_spec: Optional[pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        服务是一组路由对外暴露的入口，用于区分流量的来源和协议，实现业务、环境、逻辑租户隔离。服务可以绑定独立的访问域名，以域名维度访问业务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        apig_gateway_service_demo = bytepluscc.apig.GatewayService("ApigGatewayServiceDemo",
            service_name="ApigGatewayServiceDemo",
            gateway_id="gd3vehjs7npja181xxxxx",
            protocols=[
                "HTTP",
                "HTTPS",
            ],
            auth_spec={
                "enable": False,
            },
            comments="ApigGatewayServiceDemo-test")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/gatewayService:GatewayService example "service_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        服务是一组路由对外暴露的入口，用于区分流量的来源和协议，实现业务、环境、逻辑租户隔离。服务可以绑定独立的访问域名，以域名维度访问业务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        apig_gateway_service_demo = bytepluscc.apig.GatewayService("ApigGatewayServiceDemo",
            service_name="ApigGatewayServiceDemo",
            gateway_id="gd3vehjs7npja181xxxxx",
            protocols=[
                "HTTP",
                "HTTPS",
            ],
            auth_spec={
                "enable": False,
            },
            comments="ApigGatewayServiceDemo-test")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/gatewayService:GatewayService example "service_id"
        ```

        :param str resource_name: The name of the resource.
        :param GatewayServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_spec: Optional[pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayServiceArgs.__new__(GatewayServiceArgs)

            if auth_spec is None and not opts.urn:
                raise TypeError("Missing required property 'auth_spec'")
            __props__.__dict__["auth_spec"] = auth_spec
            __props__.__dict__["comments"] = comments
            if gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_id'")
            __props__.__dict__["gateway_id"] = gateway_id
            if protocols is None and not opts.urn:
                raise TypeError("Missing required property 'protocols'")
            __props__.__dict__["protocols"] = protocols
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["created_time"] = None
            __props__.__dict__["custom_domains"] = None
            __props__.__dict__["domain_spec"] = None
            __props__.__dict__["domains"] = None
            __props__.__dict__["gateway_name"] = None
            __props__.__dict__["message"] = None
            __props__.__dict__["service_id"] = None
            __props__.__dict__["status"] = None
        super(GatewayService, __self__).__init__(
            'bytepluscc:apig/gatewayService:GatewayService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_spec: Optional[pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']]] = None,
            comments: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayServiceCustomDomainArgs', 'GatewayServiceCustomDomainArgsDict']]]]] = None,
            domain_spec: Optional[pulumi.Input[Union['GatewayServiceDomainSpecArgs', 'GatewayServiceDomainSpecArgsDict']]] = None,
            domains: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayServiceDomainArgs', 'GatewayServiceDomainArgsDict']]]]] = None,
            gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            gateway_name: Optional[pulumi.Input[builtins.str]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            service_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'GatewayService':
        """
        Get an existing GatewayService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GatewayServiceAuthSpecArgs', 'GatewayServiceAuthSpecArgsDict']] auth_spec: 认证配置。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[Union['GatewayServiceDomainSpecArgs', 'GatewayServiceDomainSpecArgsDict']] domain_spec: 域名详情。
        :param pulumi.Input[builtins.str] gateway_id: 网关ID。
        :param pulumi.Input[builtins.str] gateway_name: 网关名称。
        :param pulumi.Input[builtins.str] message: 服务创建失败、删除失败或异常时的错误信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.str] service_name: 服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        :param pulumi.Input[builtins.str] status: Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayServiceState.__new__(_GatewayServiceState)

        __props__.__dict__["auth_spec"] = auth_spec
        __props__.__dict__["comments"] = comments
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["custom_domains"] = custom_domains
        __props__.__dict__["domain_spec"] = domain_spec
        __props__.__dict__["domains"] = domains
        __props__.__dict__["gateway_id"] = gateway_id
        __props__.__dict__["gateway_name"] = gateway_name
        __props__.__dict__["message"] = message
        __props__.__dict__["protocols"] = protocols
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        return GatewayService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authSpec")
    def auth_spec(self) -> pulumi.Output['outputs.GatewayServiceAuthSpec']:
        """
        认证配置。
        """
        return pulumi.get(self, "auth_spec")

    @property
    @pulumi.getter
    def comments(self) -> pulumi.Output[builtins.str]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> pulumi.Output[Sequence['outputs.GatewayServiceCustomDomain']]:
        return pulumi.get(self, "custom_domains")

    @property
    @pulumi.getter(name="domainSpec")
    def domain_spec(self) -> pulumi.Output['outputs.GatewayServiceDomainSpec']:
        """
        域名详情。
        """
        return pulumi.get(self, "domain_spec")

    @property
    @pulumi.getter
    def domains(self) -> pulumi.Output[Sequence['outputs.GatewayServiceDomain']]:
        return pulumi.get(self, "domains")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        网关ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        网关名称。
        """
        return pulumi.get(self, "gateway_name")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[builtins.str]:
        """
        服务创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        服务支持的协议。取值：HTTP：HTTP。HTTPS：HTTPS。
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[builtins.str]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        服务名称。支持大小写字母、数字和中划线（-），长度限制为2~128个字符。不能以中划线（-）开头。。
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Creating：创建中。CreatedFailed：创建失败。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, address_objects=None, allow_list_ids=None, allow_list_version=None, auto_storage_scaling_config=None, auto_upgrade_minor_version=None, backup_audit_log_size=None, backup_bin_log_size=None, backup_data_size=None, backup_error_log_size=None, backup_free_quota_size=None, backup_log_size=None, backup_slow_log_size=None, backup_use=None, basic_backup_binlog_size=None, basic_backup_data_size=None, charge_detail=None, cpu_num=None, created_time=None, current_kernel_version=None, db_engine_version=None, db_param_group_id=None, db_time_zone=None, deletion_protection=None, disaster_recovery_instances=None, dr_dts_task_id=None, dr_dts_task_name=None, dr_dts_task_status=None, dr_seconds_behind_master=None, endpoints=None, global_read_only=None, has_disaster_recovery_instances=None, has_green_instance=None, id=None, instance_id=None, instance_name=None, instance_status=None, instance_type=None, lower_case_table_names=None, maintenance_window=None, master_instance_id=None, master_instance_name=None, memory=None, node_cpu_used_percentage=None, node_memory_used_percentage=None, node_number=None, node_space_used_percentage=None, node_spec=None, nodes=None, port=None, project_name=None, proxy_detail=None, storage_audit_log_size=None, storage_bin_log_size=None, storage_data_size=None, storage_error_log_size=None, storage_log_size=None, storage_slow_log_size=None, storage_space=None, storage_type=None, storage_use=None, subnet_id=None, super_account_name=None, super_account_password=None, sync_mode=None, tags=None, time_zone=None, updated_time=None, vcpu=None, vpc_id=None, zone_id=None, zone_ids=None):
        if address_objects and not isinstance(address_objects, list):
            raise TypeError("Expected argument 'address_objects' to be a list")
        pulumi.set(__self__, "address_objects", address_objects)
        if allow_list_ids and not isinstance(allow_list_ids, list):
            raise TypeError("Expected argument 'allow_list_ids' to be a list")
        pulumi.set(__self__, "allow_list_ids", allow_list_ids)
        if allow_list_version and not isinstance(allow_list_version, str):
            raise TypeError("Expected argument 'allow_list_version' to be a str")
        pulumi.set(__self__, "allow_list_version", allow_list_version)
        if auto_storage_scaling_config and not isinstance(auto_storage_scaling_config, dict):
            raise TypeError("Expected argument 'auto_storage_scaling_config' to be a dict")
        pulumi.set(__self__, "auto_storage_scaling_config", auto_storage_scaling_config)
        if auto_upgrade_minor_version and not isinstance(auto_upgrade_minor_version, str):
            raise TypeError("Expected argument 'auto_upgrade_minor_version' to be a str")
        pulumi.set(__self__, "auto_upgrade_minor_version", auto_upgrade_minor_version)
        if backup_audit_log_size and not isinstance(backup_audit_log_size, int):
            raise TypeError("Expected argument 'backup_audit_log_size' to be a int")
        pulumi.set(__self__, "backup_audit_log_size", backup_audit_log_size)
        if backup_bin_log_size and not isinstance(backup_bin_log_size, int):
            raise TypeError("Expected argument 'backup_bin_log_size' to be a int")
        pulumi.set(__self__, "backup_bin_log_size", backup_bin_log_size)
        if backup_data_size and not isinstance(backup_data_size, int):
            raise TypeError("Expected argument 'backup_data_size' to be a int")
        pulumi.set(__self__, "backup_data_size", backup_data_size)
        if backup_error_log_size and not isinstance(backup_error_log_size, int):
            raise TypeError("Expected argument 'backup_error_log_size' to be a int")
        pulumi.set(__self__, "backup_error_log_size", backup_error_log_size)
        if backup_free_quota_size and not isinstance(backup_free_quota_size, int):
            raise TypeError("Expected argument 'backup_free_quota_size' to be a int")
        pulumi.set(__self__, "backup_free_quota_size", backup_free_quota_size)
        if backup_log_size and not isinstance(backup_log_size, int):
            raise TypeError("Expected argument 'backup_log_size' to be a int")
        pulumi.set(__self__, "backup_log_size", backup_log_size)
        if backup_slow_log_size and not isinstance(backup_slow_log_size, int):
            raise TypeError("Expected argument 'backup_slow_log_size' to be a int")
        pulumi.set(__self__, "backup_slow_log_size", backup_slow_log_size)
        if backup_use and not isinstance(backup_use, float):
            raise TypeError("Expected argument 'backup_use' to be a float")
        pulumi.set(__self__, "backup_use", backup_use)
        if basic_backup_binlog_size and not isinstance(basic_backup_binlog_size, int):
            raise TypeError("Expected argument 'basic_backup_binlog_size' to be a int")
        pulumi.set(__self__, "basic_backup_binlog_size", basic_backup_binlog_size)
        if basic_backup_data_size and not isinstance(basic_backup_data_size, int):
            raise TypeError("Expected argument 'basic_backup_data_size' to be a int")
        pulumi.set(__self__, "basic_backup_data_size", basic_backup_data_size)
        if charge_detail and not isinstance(charge_detail, dict):
            raise TypeError("Expected argument 'charge_detail' to be a dict")
        pulumi.set(__self__, "charge_detail", charge_detail)
        if cpu_num and not isinstance(cpu_num, int):
            raise TypeError("Expected argument 'cpu_num' to be a int")
        pulumi.set(__self__, "cpu_num", cpu_num)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if current_kernel_version and not isinstance(current_kernel_version, str):
            raise TypeError("Expected argument 'current_kernel_version' to be a str")
        pulumi.set(__self__, "current_kernel_version", current_kernel_version)
        if db_engine_version and not isinstance(db_engine_version, str):
            raise TypeError("Expected argument 'db_engine_version' to be a str")
        pulumi.set(__self__, "db_engine_version", db_engine_version)
        if db_param_group_id and not isinstance(db_param_group_id, str):
            raise TypeError("Expected argument 'db_param_group_id' to be a str")
        pulumi.set(__self__, "db_param_group_id", db_param_group_id)
        if db_time_zone and not isinstance(db_time_zone, str):
            raise TypeError("Expected argument 'db_time_zone' to be a str")
        pulumi.set(__self__, "db_time_zone", db_time_zone)
        if deletion_protection and not isinstance(deletion_protection, str):
            raise TypeError("Expected argument 'deletion_protection' to be a str")
        pulumi.set(__self__, "deletion_protection", deletion_protection)
        if disaster_recovery_instances and not isinstance(disaster_recovery_instances, list):
            raise TypeError("Expected argument 'disaster_recovery_instances' to be a list")
        pulumi.set(__self__, "disaster_recovery_instances", disaster_recovery_instances)
        if dr_dts_task_id and not isinstance(dr_dts_task_id, str):
            raise TypeError("Expected argument 'dr_dts_task_id' to be a str")
        pulumi.set(__self__, "dr_dts_task_id", dr_dts_task_id)
        if dr_dts_task_name and not isinstance(dr_dts_task_name, str):
            raise TypeError("Expected argument 'dr_dts_task_name' to be a str")
        pulumi.set(__self__, "dr_dts_task_name", dr_dts_task_name)
        if dr_dts_task_status and not isinstance(dr_dts_task_status, str):
            raise TypeError("Expected argument 'dr_dts_task_status' to be a str")
        pulumi.set(__self__, "dr_dts_task_status", dr_dts_task_status)
        if dr_seconds_behind_master and not isinstance(dr_seconds_behind_master, int):
            raise TypeError("Expected argument 'dr_seconds_behind_master' to be a int")
        pulumi.set(__self__, "dr_seconds_behind_master", dr_seconds_behind_master)
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if global_read_only and not isinstance(global_read_only, bool):
            raise TypeError("Expected argument 'global_read_only' to be a bool")
        pulumi.set(__self__, "global_read_only", global_read_only)
        if has_disaster_recovery_instances and not isinstance(has_disaster_recovery_instances, bool):
            raise TypeError("Expected argument 'has_disaster_recovery_instances' to be a bool")
        pulumi.set(__self__, "has_disaster_recovery_instances", has_disaster_recovery_instances)
        if has_green_instance and not isinstance(has_green_instance, bool):
            raise TypeError("Expected argument 'has_green_instance' to be a bool")
        pulumi.set(__self__, "has_green_instance", has_green_instance)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_status and not isinstance(instance_status, str):
            raise TypeError("Expected argument 'instance_status' to be a str")
        pulumi.set(__self__, "instance_status", instance_status)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if lower_case_table_names and not isinstance(lower_case_table_names, str):
            raise TypeError("Expected argument 'lower_case_table_names' to be a str")
        pulumi.set(__self__, "lower_case_table_names", lower_case_table_names)
        if maintenance_window and not isinstance(maintenance_window, dict):
            raise TypeError("Expected argument 'maintenance_window' to be a dict")
        pulumi.set(__self__, "maintenance_window", maintenance_window)
        if master_instance_id and not isinstance(master_instance_id, str):
            raise TypeError("Expected argument 'master_instance_id' to be a str")
        pulumi.set(__self__, "master_instance_id", master_instance_id)
        if master_instance_name and not isinstance(master_instance_name, str):
            raise TypeError("Expected argument 'master_instance_name' to be a str")
        pulumi.set(__self__, "master_instance_name", master_instance_name)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if node_cpu_used_percentage and not isinstance(node_cpu_used_percentage, float):
            raise TypeError("Expected argument 'node_cpu_used_percentage' to be a float")
        pulumi.set(__self__, "node_cpu_used_percentage", node_cpu_used_percentage)
        if node_memory_used_percentage and not isinstance(node_memory_used_percentage, float):
            raise TypeError("Expected argument 'node_memory_used_percentage' to be a float")
        pulumi.set(__self__, "node_memory_used_percentage", node_memory_used_percentage)
        if node_number and not isinstance(node_number, str):
            raise TypeError("Expected argument 'node_number' to be a str")
        pulumi.set(__self__, "node_number", node_number)
        if node_space_used_percentage and not isinstance(node_space_used_percentage, float):
            raise TypeError("Expected argument 'node_space_used_percentage' to be a float")
        pulumi.set(__self__, "node_space_used_percentage", node_space_used_percentage)
        if node_spec and not isinstance(node_spec, str):
            raise TypeError("Expected argument 'node_spec' to be a str")
        pulumi.set(__self__, "node_spec", node_spec)
        if nodes and not isinstance(nodes, list):
            raise TypeError("Expected argument 'nodes' to be a list")
        pulumi.set(__self__, "nodes", nodes)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if proxy_detail and not isinstance(proxy_detail, dict):
            raise TypeError("Expected argument 'proxy_detail' to be a dict")
        pulumi.set(__self__, "proxy_detail", proxy_detail)
        if storage_audit_log_size and not isinstance(storage_audit_log_size, int):
            raise TypeError("Expected argument 'storage_audit_log_size' to be a int")
        pulumi.set(__self__, "storage_audit_log_size", storage_audit_log_size)
        if storage_bin_log_size and not isinstance(storage_bin_log_size, int):
            raise TypeError("Expected argument 'storage_bin_log_size' to be a int")
        pulumi.set(__self__, "storage_bin_log_size", storage_bin_log_size)
        if storage_data_size and not isinstance(storage_data_size, int):
            raise TypeError("Expected argument 'storage_data_size' to be a int")
        pulumi.set(__self__, "storage_data_size", storage_data_size)
        if storage_error_log_size and not isinstance(storage_error_log_size, int):
            raise TypeError("Expected argument 'storage_error_log_size' to be a int")
        pulumi.set(__self__, "storage_error_log_size", storage_error_log_size)
        if storage_log_size and not isinstance(storage_log_size, int):
            raise TypeError("Expected argument 'storage_log_size' to be a int")
        pulumi.set(__self__, "storage_log_size", storage_log_size)
        if storage_slow_log_size and not isinstance(storage_slow_log_size, int):
            raise TypeError("Expected argument 'storage_slow_log_size' to be a int")
        pulumi.set(__self__, "storage_slow_log_size", storage_slow_log_size)
        if storage_space and not isinstance(storage_space, int):
            raise TypeError("Expected argument 'storage_space' to be a int")
        pulumi.set(__self__, "storage_space", storage_space)
        if storage_type and not isinstance(storage_type, str):
            raise TypeError("Expected argument 'storage_type' to be a str")
        pulumi.set(__self__, "storage_type", storage_type)
        if storage_use and not isinstance(storage_use, float):
            raise TypeError("Expected argument 'storage_use' to be a float")
        pulumi.set(__self__, "storage_use", storage_use)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if super_account_name and not isinstance(super_account_name, str):
            raise TypeError("Expected argument 'super_account_name' to be a str")
        pulumi.set(__self__, "super_account_name", super_account_name)
        if super_account_password and not isinstance(super_account_password, str):
            raise TypeError("Expected argument 'super_account_password' to be a str")
        pulumi.set(__self__, "super_account_password", super_account_password)
        if sync_mode and not isinstance(sync_mode, str):
            raise TypeError("Expected argument 'sync_mode' to be a str")
        pulumi.set(__self__, "sync_mode", sync_mode)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if time_zone and not isinstance(time_zone, str):
            raise TypeError("Expected argument 'time_zone' to be a str")
        pulumi.set(__self__, "time_zone", time_zone)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vcpu and not isinstance(vcpu, int):
            raise TypeError("Expected argument 'vcpu' to be a int")
        pulumi.set(__self__, "vcpu", vcpu)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)
        if zone_ids and not isinstance(zone_ids, list):
            raise TypeError("Expected argument 'zone_ids' to be a list")
        pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="addressObjects")
    def address_objects(self) -> Sequence['outputs.GetInstanceAddressObjectResult']:
        """
        默认终端的连接信息。
        """
        return pulumi.get(self, "address_objects")

    @property
    @pulumi.getter(name="allowListIds")
    def allow_list_ids(self) -> Sequence[builtins.str]:
        """
        白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        """
        return pulumi.get(self, "allow_list_ids")

    @property
    @pulumi.getter(name="allowListVersion")
    def allow_list_version(self) -> builtins.str:
        """
        白名单版本。
        """
        return pulumi.get(self, "allow_list_version")

    @property
    @pulumi.getter(name="autoStorageScalingConfig")
    def auto_storage_scaling_config(self) -> 'outputs.GetInstanceAutoStorageScalingConfigResult':
        """
        自动扩容配置。
        """
        return pulumi.get(self, "auto_storage_scaling_config")

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> builtins.str:
        """
        实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @property
    @pulumi.getter(name="backupAuditLogSize")
    def backup_audit_log_size(self) -> builtins.int:
        """
        备份中审计日志使用的空间。
        """
        return pulumi.get(self, "backup_audit_log_size")

    @property
    @pulumi.getter(name="backupBinLogSize")
    def backup_bin_log_size(self) -> builtins.int:
        """
        备份中 Binlog 日志使用的空间。
        """
        return pulumi.get(self, "backup_bin_log_size")

    @property
    @pulumi.getter(name="backupDataSize")
    def backup_data_size(self) -> builtins.int:
        """
        备份中数据使用的空间。
        """
        return pulumi.get(self, "backup_data_size")

    @property
    @pulumi.getter(name="backupErrorLogSize")
    def backup_error_log_size(self) -> builtins.int:
        """
        备份中错误日志使用的空间。
        """
        return pulumi.get(self, "backup_error_log_size")

    @property
    @pulumi.getter(name="backupFreeQuotaSize")
    def backup_free_quota_size(self) -> builtins.int:
        """
        免费的备份存储空间，单位为 GB。
        """
        return pulumi.get(self, "backup_free_quota_size")

    @property
    @pulumi.getter(name="backupLogSize")
    def backup_log_size(self) -> builtins.int:
        """
        备份中日志使用的空间。
        """
        return pulumi.get(self, "backup_log_size")

    @property
    @pulumi.getter(name="backupSlowLogSize")
    def backup_slow_log_size(self) -> builtins.int:
        """
        备份中慢日志使用的空间。
        """
        return pulumi.get(self, "backup_slow_log_size")

    @property
    @pulumi.getter(name="backupUse")
    def backup_use(self) -> builtins.float:
        """
        实例的备份已使用的空间，单位为 GB。
        """
        return pulumi.get(self, "backup_use")

    @property
    @pulumi.getter(name="basicBackupBinlogSize")
    def basic_backup_binlog_size(self) -> builtins.int:
        """
        基础备份中 Binlog 日志使用的空间。
        """
        return pulumi.get(self, "basic_backup_binlog_size")

    @property
    @pulumi.getter(name="basicBackupDataSize")
    def basic_backup_data_size(self) -> builtins.int:
        """
        基础备份中数据使用的空间。
        """
        return pulumi.get(self, "basic_backup_data_size")

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> 'outputs.GetInstanceChargeDetailResult':
        """
        付费方式。
        """
        return pulumi.get(self, "charge_detail")

    @property
    @pulumi.getter(name="cpuNum")
    def cpu_num(self) -> builtins.int:
        """
        实例数据库代理服务的 CPU 核数。
        """
        return pulumi.get(self, "cpu_num")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        实例创建本地时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="currentKernelVersion")
    def current_kernel_version(self) -> builtins.str:
        """
        实例的内核小版本。
        """
        return pulumi.get(self, "current_kernel_version")

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> builtins.str:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @property
    @pulumi.getter(name="dbParamGroupId")
    def db_param_group_id(self) -> builtins.str:
        """
        参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        """
        return pulumi.get(self, "db_param_group_id")

    @property
    @pulumi.getter(name="dbTimeZone")
    def db_time_zone(self) -> builtins.str:
        """
        时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        """
        return pulumi.get(self, "db_time_zone")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> builtins.str:
        """
        是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        """
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter(name="disasterRecoveryInstances")
    def disaster_recovery_instances(self) -> Sequence['outputs.GetInstanceDisasterRecoveryInstanceResult']:
        """
        实例的灾备实例的信息。
        """
        return pulumi.get(self, "disaster_recovery_instances")

    @property
    @pulumi.getter(name="drDtsTaskId")
    def dr_dts_task_id(self) -> builtins.str:
        """
        主实例与灾备实例之间的数据同步链路在 DTS 数据同步任务的 ID。
        """
        return pulumi.get(self, "dr_dts_task_id")

    @property
    @pulumi.getter(name="drDtsTaskName")
    def dr_dts_task_name(self) -> builtins.str:
        """
        主实例与灾备实例之间同步任务的名称。
        """
        return pulumi.get(self, "dr_dts_task_name")

    @property
    @pulumi.getter(name="drDtsTaskStatus")
    def dr_dts_task_status(self) -> builtins.str:
        """
        主实例与灾备实例之间同步任务的状态。
        """
        return pulumi.get(self, "dr_dts_task_status")

    @property
    @pulumi.getter(name="drSecondsBehindMaster")
    def dr_seconds_behind_master(self) -> builtins.int:
        """
        灾备实例与主实例之间的时延。
        """
        return pulumi.get(self, "dr_seconds_behind_master")

    @property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetInstanceEndpointResult']:
        """
        实例的连接信息。
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="globalReadOnly")
    def global_read_only(self) -> builtins.bool:
        """
        是否开启全局只读。取值：true：是。false：否。默认值为 false。
        """
        return pulumi.get(self, "global_read_only")

    @property
    @pulumi.getter(name="hasDisasterRecoveryInstances")
    def has_disaster_recovery_instances(self) -> builtins.bool:
        """
        实例是否有灾备实例。取值：true：是。false：否。
        """
        return pulumi.get(self, "has_disaster_recovery_instances")

    @property
    @pulumi.getter(name="hasGreenInstance")
    def has_green_instance(self) -> builtins.bool:
        """
        实例是否处于蓝绿部署中。取值：true：是。false：否。
        """
        return pulumi.get(self, "has_green_instance")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> builtins.str:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="lowerCaseTableNames")
    def lower_case_table_names(self) -> builtins.str:
        """
        表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        """
        return pulumi.get(self, "lower_case_table_names")

    @property
    @pulumi.getter(name="maintenanceWindow")
    def maintenance_window(self) -> 'outputs.GetInstanceMaintenanceWindowResult':
        """
        在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        """
        return pulumi.get(self, "maintenance_window")

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> builtins.str:
        """
        主实例的 ID。
        """
        return pulumi.get(self, "master_instance_id")

    @property
    @pulumi.getter(name="masterInstanceName")
    def master_instance_name(self) -> builtins.str:
        """
        主实例的名称。
        """
        return pulumi.get(self, "master_instance_name")

    @property
    @pulumi.getter
    def memory(self) -> builtins.int:
        """
        内存大小。单位：GB。
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="nodeCpuUsedPercentage")
    def node_cpu_used_percentage(self) -> builtins.float:
        """
        实例主节点 CPU 使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_cpu_used_percentage")

    @property
    @pulumi.getter(name="nodeMemoryUsedPercentage")
    def node_memory_used_percentage(self) -> builtins.float:
        """
        实例主节点内存使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_memory_used_percentage")

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> builtins.str:
        """
        节点数量。
        """
        return pulumi.get(self, "node_number")

    @property
    @pulumi.getter(name="nodeSpaceUsedPercentage")
    def node_space_used_percentage(self) -> builtins.float:
        """
        实例主节点磁盘使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_space_used_percentage")

    @property
    @pulumi.getter(name="nodeSpec")
    def node_spec(self) -> builtins.str:
        """
        节点规格。
        """
        return pulumi.get(self, "node_spec")

    @property
    @pulumi.getter
    def nodes(self) -> Sequence['outputs.GetInstanceNodeResult']:
        """
        实例节点信息。
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        所属项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="proxyDetail")
    def proxy_detail(self) -> 'outputs.GetInstanceProxyDetailResult':
        """
        proxy信息
        """
        return pulumi.get(self, "proxy_detail")

    @property
    @pulumi.getter(name="storageAuditLogSize")
    def storage_audit_log_size(self) -> builtins.int:
        """
        实例存储空间中审计日志使用的空间。
        """
        return pulumi.get(self, "storage_audit_log_size")

    @property
    @pulumi.getter(name="storageBinLogSize")
    def storage_bin_log_size(self) -> builtins.int:
        """
        实例存储空间中 Binlog 使用的空间。
        """
        return pulumi.get(self, "storage_bin_log_size")

    @property
    @pulumi.getter(name="storageDataSize")
    def storage_data_size(self) -> builtins.int:
        """
        实例存储空间中数据使用的空间。
        """
        return pulumi.get(self, "storage_data_size")

    @property
    @pulumi.getter(name="storageErrorLogSize")
    def storage_error_log_size(self) -> builtins.int:
        """
        实例存储空间中错误日志使用的空间。
        """
        return pulumi.get(self, "storage_error_log_size")

    @property
    @pulumi.getter(name="storageLogSize")
    def storage_log_size(self) -> builtins.int:
        """
        实例存储空间中日志使用的空间。
        """
        return pulumi.get(self, "storage_log_size")

    @property
    @pulumi.getter(name="storageSlowLogSize")
    def storage_slow_log_size(self) -> builtins.int:
        """
        实例存储空间中慢日志使用的空间。
        """
        return pulumi.get(self, "storage_slow_log_size")

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> builtins.int:
        """
        实例总存储空间。单位为 GB。
        """
        return pulumi.get(self, "storage_space")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> builtins.str:
        """
        实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="storageUse")
    def storage_use(self) -> builtins.float:
        """
        实例已使用用存储空间，单位为 GB。
        """
        return pulumi.get(self, "storage_use")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="superAccountName")
    def super_account_name(self) -> builtins.str:
        """
        高权限账号名称。不传此参数默认不创建高权限账号。
        """
        return pulumi.get(self, "super_account_name")

    @property
    @pulumi.getter(name="superAccountPassword")
    def super_account_password(self) -> builtins.str:
        """
        高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "super_account_password")

    @property
    @pulumi.getter(name="syncMode")
    def sync_mode(self) -> builtins.str:
        """
        数据同步方式：SemiSync：半同步。Async：异步。
        """
        return pulumi.get(self, "sync_mode")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        """
        RDS MySQL 实例的标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> builtins.str:
        """
        时区。
        """
        return pulumi.get(self, "time_zone")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        实例更新本地时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter
    def vcpu(self) -> builtins.int:
        """
        CPU 大小。例如：1 表示 1U。
        """
        return pulumi.get(self, "vcpu")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        专有网络（VPC） ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        实例主节点所在可用区。
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Sequence[builtins.str]:
        """
        实例各节点所在的可用区列表。
        """
        return pulumi.get(self, "zone_ids")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            address_objects=self.address_objects,
            allow_list_ids=self.allow_list_ids,
            allow_list_version=self.allow_list_version,
            auto_storage_scaling_config=self.auto_storage_scaling_config,
            auto_upgrade_minor_version=self.auto_upgrade_minor_version,
            backup_audit_log_size=self.backup_audit_log_size,
            backup_bin_log_size=self.backup_bin_log_size,
            backup_data_size=self.backup_data_size,
            backup_error_log_size=self.backup_error_log_size,
            backup_free_quota_size=self.backup_free_quota_size,
            backup_log_size=self.backup_log_size,
            backup_slow_log_size=self.backup_slow_log_size,
            backup_use=self.backup_use,
            basic_backup_binlog_size=self.basic_backup_binlog_size,
            basic_backup_data_size=self.basic_backup_data_size,
            charge_detail=self.charge_detail,
            cpu_num=self.cpu_num,
            created_time=self.created_time,
            current_kernel_version=self.current_kernel_version,
            db_engine_version=self.db_engine_version,
            db_param_group_id=self.db_param_group_id,
            db_time_zone=self.db_time_zone,
            deletion_protection=self.deletion_protection,
            disaster_recovery_instances=self.disaster_recovery_instances,
            dr_dts_task_id=self.dr_dts_task_id,
            dr_dts_task_name=self.dr_dts_task_name,
            dr_dts_task_status=self.dr_dts_task_status,
            dr_seconds_behind_master=self.dr_seconds_behind_master,
            endpoints=self.endpoints,
            global_read_only=self.global_read_only,
            has_disaster_recovery_instances=self.has_disaster_recovery_instances,
            has_green_instance=self.has_green_instance,
            id=self.id,
            instance_id=self.instance_id,
            instance_name=self.instance_name,
            instance_status=self.instance_status,
            instance_type=self.instance_type,
            lower_case_table_names=self.lower_case_table_names,
            maintenance_window=self.maintenance_window,
            master_instance_id=self.master_instance_id,
            master_instance_name=self.master_instance_name,
            memory=self.memory,
            node_cpu_used_percentage=self.node_cpu_used_percentage,
            node_memory_used_percentage=self.node_memory_used_percentage,
            node_number=self.node_number,
            node_space_used_percentage=self.node_space_used_percentage,
            node_spec=self.node_spec,
            nodes=self.nodes,
            port=self.port,
            project_name=self.project_name,
            proxy_detail=self.proxy_detail,
            storage_audit_log_size=self.storage_audit_log_size,
            storage_bin_log_size=self.storage_bin_log_size,
            storage_data_size=self.storage_data_size,
            storage_error_log_size=self.storage_error_log_size,
            storage_log_size=self.storage_log_size,
            storage_slow_log_size=self.storage_slow_log_size,
            storage_space=self.storage_space,
            storage_type=self.storage_type,
            storage_use=self.storage_use,
            subnet_id=self.subnet_id,
            super_account_name=self.super_account_name,
            super_account_password=self.super_account_password,
            sync_mode=self.sync_mode,
            tags=self.tags,
            time_zone=self.time_zone,
            updated_time=self.updated_time,
            vcpu=self.vcpu,
            vpc_id=self.vpc_id,
            zone_id=self.zone_id,
            zone_ids=self.zone_ids)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::RDSMySQL::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdsmysql/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        address_objects=pulumi.get(__ret__, 'address_objects'),
        allow_list_ids=pulumi.get(__ret__, 'allow_list_ids'),
        allow_list_version=pulumi.get(__ret__, 'allow_list_version'),
        auto_storage_scaling_config=pulumi.get(__ret__, 'auto_storage_scaling_config'),
        auto_upgrade_minor_version=pulumi.get(__ret__, 'auto_upgrade_minor_version'),
        backup_audit_log_size=pulumi.get(__ret__, 'backup_audit_log_size'),
        backup_bin_log_size=pulumi.get(__ret__, 'backup_bin_log_size'),
        backup_data_size=pulumi.get(__ret__, 'backup_data_size'),
        backup_error_log_size=pulumi.get(__ret__, 'backup_error_log_size'),
        backup_free_quota_size=pulumi.get(__ret__, 'backup_free_quota_size'),
        backup_log_size=pulumi.get(__ret__, 'backup_log_size'),
        backup_slow_log_size=pulumi.get(__ret__, 'backup_slow_log_size'),
        backup_use=pulumi.get(__ret__, 'backup_use'),
        basic_backup_binlog_size=pulumi.get(__ret__, 'basic_backup_binlog_size'),
        basic_backup_data_size=pulumi.get(__ret__, 'basic_backup_data_size'),
        charge_detail=pulumi.get(__ret__, 'charge_detail'),
        cpu_num=pulumi.get(__ret__, 'cpu_num'),
        created_time=pulumi.get(__ret__, 'created_time'),
        current_kernel_version=pulumi.get(__ret__, 'current_kernel_version'),
        db_engine_version=pulumi.get(__ret__, 'db_engine_version'),
        db_param_group_id=pulumi.get(__ret__, 'db_param_group_id'),
        db_time_zone=pulumi.get(__ret__, 'db_time_zone'),
        deletion_protection=pulumi.get(__ret__, 'deletion_protection'),
        disaster_recovery_instances=pulumi.get(__ret__, 'disaster_recovery_instances'),
        dr_dts_task_id=pulumi.get(__ret__, 'dr_dts_task_id'),
        dr_dts_task_name=pulumi.get(__ret__, 'dr_dts_task_name'),
        dr_dts_task_status=pulumi.get(__ret__, 'dr_dts_task_status'),
        dr_seconds_behind_master=pulumi.get(__ret__, 'dr_seconds_behind_master'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        global_read_only=pulumi.get(__ret__, 'global_read_only'),
        has_disaster_recovery_instances=pulumi.get(__ret__, 'has_disaster_recovery_instances'),
        has_green_instance=pulumi.get(__ret__, 'has_green_instance'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_status=pulumi.get(__ret__, 'instance_status'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        lower_case_table_names=pulumi.get(__ret__, 'lower_case_table_names'),
        maintenance_window=pulumi.get(__ret__, 'maintenance_window'),
        master_instance_id=pulumi.get(__ret__, 'master_instance_id'),
        master_instance_name=pulumi.get(__ret__, 'master_instance_name'),
        memory=pulumi.get(__ret__, 'memory'),
        node_cpu_used_percentage=pulumi.get(__ret__, 'node_cpu_used_percentage'),
        node_memory_used_percentage=pulumi.get(__ret__, 'node_memory_used_percentage'),
        node_number=pulumi.get(__ret__, 'node_number'),
        node_space_used_percentage=pulumi.get(__ret__, 'node_space_used_percentage'),
        node_spec=pulumi.get(__ret__, 'node_spec'),
        nodes=pulumi.get(__ret__, 'nodes'),
        port=pulumi.get(__ret__, 'port'),
        project_name=pulumi.get(__ret__, 'project_name'),
        proxy_detail=pulumi.get(__ret__, 'proxy_detail'),
        storage_audit_log_size=pulumi.get(__ret__, 'storage_audit_log_size'),
        storage_bin_log_size=pulumi.get(__ret__, 'storage_bin_log_size'),
        storage_data_size=pulumi.get(__ret__, 'storage_data_size'),
        storage_error_log_size=pulumi.get(__ret__, 'storage_error_log_size'),
        storage_log_size=pulumi.get(__ret__, 'storage_log_size'),
        storage_slow_log_size=pulumi.get(__ret__, 'storage_slow_log_size'),
        storage_space=pulumi.get(__ret__, 'storage_space'),
        storage_type=pulumi.get(__ret__, 'storage_type'),
        storage_use=pulumi.get(__ret__, 'storage_use'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        super_account_name=pulumi.get(__ret__, 'super_account_name'),
        super_account_password=pulumi.get(__ret__, 'super_account_password'),
        sync_mode=pulumi.get(__ret__, 'sync_mode'),
        tags=pulumi.get(__ret__, 'tags'),
        time_zone=pulumi.get(__ret__, 'time_zone'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vcpu=pulumi.get(__ret__, 'vcpu'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_id=pulumi.get(__ret__, 'zone_id'),
        zone_ids=pulumi.get(__ret__, 'zone_ids'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::RDSMySQL::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdsmysql/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        address_objects=pulumi.get(__response__, 'address_objects'),
        allow_list_ids=pulumi.get(__response__, 'allow_list_ids'),
        allow_list_version=pulumi.get(__response__, 'allow_list_version'),
        auto_storage_scaling_config=pulumi.get(__response__, 'auto_storage_scaling_config'),
        auto_upgrade_minor_version=pulumi.get(__response__, 'auto_upgrade_minor_version'),
        backup_audit_log_size=pulumi.get(__response__, 'backup_audit_log_size'),
        backup_bin_log_size=pulumi.get(__response__, 'backup_bin_log_size'),
        backup_data_size=pulumi.get(__response__, 'backup_data_size'),
        backup_error_log_size=pulumi.get(__response__, 'backup_error_log_size'),
        backup_free_quota_size=pulumi.get(__response__, 'backup_free_quota_size'),
        backup_log_size=pulumi.get(__response__, 'backup_log_size'),
        backup_slow_log_size=pulumi.get(__response__, 'backup_slow_log_size'),
        backup_use=pulumi.get(__response__, 'backup_use'),
        basic_backup_binlog_size=pulumi.get(__response__, 'basic_backup_binlog_size'),
        basic_backup_data_size=pulumi.get(__response__, 'basic_backup_data_size'),
        charge_detail=pulumi.get(__response__, 'charge_detail'),
        cpu_num=pulumi.get(__response__, 'cpu_num'),
        created_time=pulumi.get(__response__, 'created_time'),
        current_kernel_version=pulumi.get(__response__, 'current_kernel_version'),
        db_engine_version=pulumi.get(__response__, 'db_engine_version'),
        db_param_group_id=pulumi.get(__response__, 'db_param_group_id'),
        db_time_zone=pulumi.get(__response__, 'db_time_zone'),
        deletion_protection=pulumi.get(__response__, 'deletion_protection'),
        disaster_recovery_instances=pulumi.get(__response__, 'disaster_recovery_instances'),
        dr_dts_task_id=pulumi.get(__response__, 'dr_dts_task_id'),
        dr_dts_task_name=pulumi.get(__response__, 'dr_dts_task_name'),
        dr_dts_task_status=pulumi.get(__response__, 'dr_dts_task_status'),
        dr_seconds_behind_master=pulumi.get(__response__, 'dr_seconds_behind_master'),
        endpoints=pulumi.get(__response__, 'endpoints'),
        global_read_only=pulumi.get(__response__, 'global_read_only'),
        has_disaster_recovery_instances=pulumi.get(__response__, 'has_disaster_recovery_instances'),
        has_green_instance=pulumi.get(__response__, 'has_green_instance'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_status=pulumi.get(__response__, 'instance_status'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        lower_case_table_names=pulumi.get(__response__, 'lower_case_table_names'),
        maintenance_window=pulumi.get(__response__, 'maintenance_window'),
        master_instance_id=pulumi.get(__response__, 'master_instance_id'),
        master_instance_name=pulumi.get(__response__, 'master_instance_name'),
        memory=pulumi.get(__response__, 'memory'),
        node_cpu_used_percentage=pulumi.get(__response__, 'node_cpu_used_percentage'),
        node_memory_used_percentage=pulumi.get(__response__, 'node_memory_used_percentage'),
        node_number=pulumi.get(__response__, 'node_number'),
        node_space_used_percentage=pulumi.get(__response__, 'node_space_used_percentage'),
        node_spec=pulumi.get(__response__, 'node_spec'),
        nodes=pulumi.get(__response__, 'nodes'),
        port=pulumi.get(__response__, 'port'),
        project_name=pulumi.get(__response__, 'project_name'),
        proxy_detail=pulumi.get(__response__, 'proxy_detail'),
        storage_audit_log_size=pulumi.get(__response__, 'storage_audit_log_size'),
        storage_bin_log_size=pulumi.get(__response__, 'storage_bin_log_size'),
        storage_data_size=pulumi.get(__response__, 'storage_data_size'),
        storage_error_log_size=pulumi.get(__response__, 'storage_error_log_size'),
        storage_log_size=pulumi.get(__response__, 'storage_log_size'),
        storage_slow_log_size=pulumi.get(__response__, 'storage_slow_log_size'),
        storage_space=pulumi.get(__response__, 'storage_space'),
        storage_type=pulumi.get(__response__, 'storage_type'),
        storage_use=pulumi.get(__response__, 'storage_use'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        super_account_name=pulumi.get(__response__, 'super_account_name'),
        super_account_password=pulumi.get(__response__, 'super_account_password'),
        sync_mode=pulumi.get(__response__, 'sync_mode'),
        tags=pulumi.get(__response__, 'tags'),
        time_zone=pulumi.get(__response__, 'time_zone'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vcpu=pulumi.get(__response__, 'vcpu'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_id=pulumi.get(__response__, 'zone_id'),
        zone_ids=pulumi.get(__response__, 'zone_ids')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEndpointArgs',
    'InstanceEndpointArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceEndpointArgsDict(TypedDict):
        address_type: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        """
        eip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        """
        endpoint_id: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        """
        endpoint_str: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        """
        network_type: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        """
        private_dns_visibility: NotRequired[pulumi.Input[builtins.bool]]
        """
        私网域名是否开启公网解析。
        """
elif False:
    InstanceEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointArgs:
    def __init__(__self__, *,
                 address_type: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_str: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 private_dns_visibility: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.str] address_type: 连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        :param pulumi.Input[builtins.str] eip_id: 当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        :param pulumi.Input[builtins.str] endpoint_id: 连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        :param pulumi.Input[builtins.str] endpoint_str: 连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        :param pulumi.Input[builtins.str] network_type: 连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        :param pulumi.Input[builtins.bool] private_dns_visibility: 私网域名是否开启公网解析。
        """
        if address_type is not None:
            pulumi.set(__self__, "address_type", address_type)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_str is not None:
            pulumi.set(__self__, "endpoint_str", endpoint_str)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if private_dns_visibility is not None:
            pulumi.set(__self__, "private_dns_visibility", private_dns_visibility)

    @property
    @pulumi.getter(name="addressType")
    def address_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        """
        return pulumi.get(self, "address_type")

    @address_type.setter
    def address_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address_type", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @property
    @pulumi.getter(name="endpointStr")
    def endpoint_str(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_str")

    @endpoint_str.setter
    def endpoint_str(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_str", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter(name="privateDnsVisibility")
    def private_dns_visibility(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        私网域名是否开启公网解析。
        """
        return pulumi.get(self, "private_dns_visibility")

    @private_dns_visibility.setter
    def private_dns_visibility(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "private_dns_visibility", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        实例所绑定标签的标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        实例所绑定标签的标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 实例所绑定标签的标签键。
        :param pulumi.Input[builtins.str] value: 实例所绑定标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所绑定标签的标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所绑定标签的标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


